..
   Do not edit this .rst file directly — it’s generated programmatically.
   See doc/reference.sh.

==================================================
Module: ``cache``
==================================================

`Leer en español </es/latest/reference/cache.html>`_

- **update cache**
- **read cache**

**COMMANDS**


**update cache**

Create web browser cached file override ID.

*Example*

.. code:: sh

    $ cpanel update cache

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/update/

**read cache**

Return web browser cached file override ID.

*Example*

.. code:: sh

    $ cpanel read cache

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/CacheBuster-read/


